==> kwin-5.23.5.tar.xz: kwin-5.23.5/src/kcmkwin/kwindecoration/window-decorations.knsrc.cmake <==
[KNewStuff3]
Name=Window Decorations
Name[ar]=زخارف النوافذ
Name[az]=Pəncərə dekorasiyası
Name[bg]=Декорации на прозорците
Name[bs]=Dekoracije prozora
Name[ca]=Decoració de les finestres
Name[ca@valencia]=Decoració de les finestres
Name[cs]=Dekorace oken
Name[da]=Vinduesdekorationer
Name[de]=Fensterdekoration
Name[el]=Διακοσμήσεις παραθύρου
Name[en_GB]=Window Decorations
Name[es]=Decoraciones de las ventanas
Name[et]=Akna dekoratsioonid
Name[eu]=Leiho-apaindurak
Name[fi]=Ikkunakehykset
Name[fr]=Décorations de fenêtres
Name[ga]=Maisiúcháin Fhuinneog
Name[gl]=Decoración da xanela
Name[he]=מסגרת חלון
Name[hi]=विंडो सजावट
Name[hr]=Ukrasi prozora
Name[hu]=Ablakdekorációk
Name[ia]=Decorationes de fenestra
Name[id]=Dekorasi Window
Name[is]=Gluggaskreytingar
Name[it]=Decorazioni delle finestre
Name[ja]=ウィンドウの飾り
Name[kk]=Терезенің безендірулері
Name[km]=ការ​តុបតែង​បង្អួច
Name[kn]=ವಿಂಡೋ ಅಲಂಕಾರಗಳು
Name[ko]=창 장식
Name[lt]=Langų dekoracijos
Name[lv]=Logu dekorācijas
Name[mr]=चौकट सजावट
Name[nb]=Vinduspynt
Name[nds]=Finstern opfladusen
Name[nl]=Vensterdecoraties
Name[nn]=Vindaugspynt
Name[pa]=ਵਿੰਡੋ ਸਜਾਵਟ
Name[pl]=Wygląd okien
Name[pt]=Decorações das Janelas
Name[pt_BR]=Decorações da janela
Name[ro]=Decorații fereastră
Name[ru]=Оформление окон
Name[si]=කවුළු සැරසිලි
Name[sk]=Dekorácie okien
Name[sl]=Okraski oken
Name[sr]=Декорације прозора
Name[sr@ijekavian]=Декорације прозора
Name[sr@ijekavianlatin]=Dekoracije prozora
Name[sr@latin]=Dekoracije prozora
Name[sv]=Fönsterdekorationer
Name[th]=ส่วนตกแต่งหน้าต่าง
Name[tr]=Pencere Dekorasyonları
Name[ug]=كۆزنەك بېزەكلىرى
Name[uk]=Обрамлення вікон
Name[wa]=Gåyotaedjes des fniesses
Name[x-test]=xxWindow Decorationsxx
Name[zh_CN]=窗口装饰元素
Name[zh_TW]=視窗裝飾

ProvidersUrl=https://autoconfig.kde.org/ocs/providers.xml
Categories=Window Decoration Aurorae
TargetDir=aurorae/themes
Uncompress=archive
AdoptionCommand=@KDE_INSTALL_LIBEXECDIR@/kwin-applywindowdecoration %f

==> kwin-5.25.4.tar.xz: kwin-5.25.4/src/kcmkwin/kwindecoration/window-decorations.knsrc.cmake <==
[KNewStuff3]
Name=Window Decorations
Name[ar]=زخارف النوافذ
Name[az]=Pəncərə dekorasiyası
Name[bg]=Декорации на прозорците
Name[bs]=Dekoracije prozora
Name[ca]=Decoració de les finestres
Name[ca@valencia]=Decoració de les finestres
Name[cs]=Dekorace oken
Name[da]=Vinduesdekorationer
Name[de]=Fensterdekoration
Name[el]=Διακοσμήσεις παραθύρου
Name[en_GB]=Window Decorations
Name[es]=Decoraciones de las ventanas
Name[et]=Akna dekoratsioonid
Name[eu]=Leiho-apaindurak
Name[fi]=Ikkunakehykset
Name[fr]=Décorations de fenêtres
Name[ga]=Maisiúcháin Fhuinneog
Name[gl]=Decoración da xanela
Name[he]=מסגרת חלון
Name[hi]=विंडो सजावट
Name[hr]=Ukrasi prozora
Name[hu]=Ablakdekorációk
Name[ia]=Decorationes de fenestra
Name[id]=Dekorasi Window
Name[is]=Gluggaskreytingar
Name[it]=Decorazioni delle finestre
Name[ja]=ウィンドウの飾り
Name[kk]=Терезенің безендірулері
Name[km]=ការ​តុបតែង​បង្អួច
Name[kn]=ವಿಂಡೋ ಅಲಂಕಾರಗಳು
Name[ko]=창 장식
Name[lt]=Langų dekoracijos
Name[lv]=Logu dekorācijas
Name[mr]=चौकट सजावट
Name[nb]=Vinduspynt
Name[nds]=Finstern opfladusen
Name[nl]=Vensterdecoraties
Name[nn]=Vindaugspynt
Name[pa]=ਵਿੰਡੋ ਸਜਾਵਟ
Name[pl]=Wygląd okien
Name[pt]=Decorações das Janelas
Name[pt_BR]=Decorações da janela
Name[ro]=Decorații fereastră
Name[ru]=Оформление окон
Name[si]=කවුළු සැරසිලි
Name[sk]=Dekorácie okien
Name[sl]=Okraski oken
Name[sr]=Декорације прозора
Name[sr@ijekavian]=Декорације прозора
Name[sr@ijekavianlatin]=Dekoracije prozora
Name[sr@latin]=Dekoracije prozora
Name[sv]=Fönsterdekorationer
Name[th]=ส่วนตกแต่งหน้าต่าง
Name[tr]=Pencere Dekorasyonları
Name[ug]=كۆزنەك بېزەكلىرى
Name[uk]=Обрамлення вікон
Name[wa]=Gåyotaedjes des fniesses
Name[x-test]=xxWindow Decorationsxx
Name[zh_CN]=窗口装饰元素
Name[zh_TW]=視窗裝飾

ProvidersUrl=https://autoconfig.kde.org/ocs/providers.xml
Categories=Window Decoration Aurorae
TargetDir=aurorae/themes
Uncompress=archive
AdoptionCommand=@KDE_INSTALL_FULL_LIBEXECDIR@/kwin-applywindowdecoration %f
